@@ -16,7 +16,7 @@ sshzd <- function(formula,type=NULL,data=list(),alpha=1.4,
         if (any(start>time))
             stop("gss error in sshzd: start after follow-up time")
         if (min(start)<0)
-            warning("gss warning in sshzd: start before time 0")
+            stop("gss error in sshzd: start before time 0")
         time <- cbind(start,time)
         list(tname=tname,start=time[,1],end=time[,2],status=as.logical(status))
     }
@@ -70,7 +70,9 @@ sshzd <- function(formula,type=NULL,data=list(),alpha=1.4,
         id.wk <- c(id.wk,(1:nT)[(1:nobs)[yy$status]%in%id.basis[i]])
     }
     ## set domain and type for time
-    tdomain <- c(min(yy$start),max(yy$end))
+    mn <- min(yy$start)
+    mx <- max(yy$end)
+    tdomain <- c(max(mn-.05*(mx-mn),0),mx)
     if (is.null(type[[tname]])) type[[tname]] <- list("cubic",tdomain)
     if (length(type[[tname]])==1) type[[tname]] <- c(type[[tname]],tdomain)
     if (!(type[[tname]][[1]]%in%c("cubic","linear")))
@@ -82,7 +84,7 @@ sshzd <- function(formula,type=NULL,data=list(),alpha=1.4,
     term <- mkterm(mf,type)
     ## Generate random
     if (!is.null(random)) {
-        if (class(random)=="formula") random <- mkran(random,data)
+        if (inherits(random,"formula")) random <- mkran(random,data)
     }
     ## Generate Gauss-Legendre quadrature
     nmesh <- 200
@@ -428,12 +430,14 @@ msphzd <- function(s,r,id.wk,Nobs,cnt,qd.s,qd.r,qd.wt,random,prec,maxiter,alpha,
         cv <- (zz$min-cv.shift)/cv.scale
     }
     else {
+        mn0 <- log.la0-6
+        mx0 <- log.la0+6
         repeat {
-            mn <- la-1
-            mx <- la+1
-            if (mx>log.la0+6) break
+            mn <- max(la-1,mn0)
+            mx <- min(la+1,mx0)
             zz <- nlm0(cv.s,c(mn,mx))
-            if (min(zz$est-mn,mx-zz$est)>=1e-3) break
+            if ((min(zz$est-mn,mx-zz$est)>=1e-1)||
+                (min(zz$est-mn0,mx0-zz$est)<1e-1)) break
             else la <- zz$est
         }
         cv <- zz$min
@@ -536,12 +540,14 @@ msphzd <- function(s,r,id.wk,Nobs,cnt,qd.s,qd.r,qd.wt,random,prec,maxiter,alpha,
         cv <- (zz$min-cv.shift)/cv.scale
     }
     else {
+        mn0 <- log.la0-6
+        mx0 <- log.la0+6
         repeat {
-            mn <- la-1
-            mx <- la+1
-            if (mx>log.la0+6) break
+            mn <- max(la-1,mn0)
+            mx <- min(la+1,mx0)
             zz <- nlm0(cv.s,c(mn,mx))
-            if (min(zz$est-mn,mx-zz$est)>=1e-3) break
+            if ((min(zz$est-mn,mx-zz$est)>=1e-1)||
+                (min(zz$est-mn0,mx0-zz$est)<1e-1)) break
             else la <- zz$est
         }
         cv <- zz$min
